Windows Live - velruse.providers.live — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »

# Windows Live - `velruse.providers.live`

The Windows Live Provider supports the Windows Live OAuth 2.0 API.

Note

The Return URL for velruse must be registered with Live Services as Return URL.

Example Return URL:

    http://YOURDOMAIN.COM/velruse/live/process

Windows Live Developer Links:

- Windows Live
- Windows Live OAuth 2.0 SDK

## Settings

`client_id`
  Component Application ID
`client_secret`
  Component Secret Key
`scope`
  Delegated auth Offers, e.g. Contacts.View The Offers parameter is optional to invoke Delegated Authentication.

## POST Parameters

Complete Example:

    <form action="/velruse/live/auth" method="post">
        <input type="submit" value="Login with Windows Live" />
    </form>

## Pyramid API

Live Authentication Views

class `LiveAuthenticationComplete`(profile=None, credentials=None, provider_name=None, provider_type=None)

  Bases: `velruse.AuthenticationComplete`

  Live Connect auth complete

`includeme`(config)

`add_live_login`(config, consumer_key, consumer_secret, scope=None, login_path='/login/live', callback_path='/login/live/callback', name='live')

  Add a Live login provider to the application.

`add_live_login_from_settings`(config, prefix='velruse.live.')

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »